class TeamDataException(Exception):
    """Handles TeamData Exceptions"""


class TeamData:
    """Handles Team Data requests"""

    def __init__(self, season, team):
        self.profile_data = self._get_profile(season, team)
        self.match_data = self._get_match_data(season)
        self.projected_data = self._get_projected_data(season)

    def _get_profile(self, season, team):
        """
        Returns profile data of the team

        @param team - id or name of the team to look up
        """
        try:
            try:
                team = int(team)
            except ValueError:
                team = team.lower()
            team_list = season.get_season_data()["proTeams"]
            for t in team_list:
                if t["id"] == team:
                    return t
                if t["name"].lower() == team:
                    return t
        except Exception as e:
            error_msg = ("Failed to retrieve team profile data: {}"
                         "".format(str(e)))
            raise TeamDataException(error_msg)

    def _get_match_data(self, season):
        """
        Returns match data related to team
        """
        try:
            match_data = []
            team_id = self.profile_data["id"]
            matches = season.get_season_data()["stats"]["actualTeamStats"]
            for match in matches:
                if team_id == match[0]:
                    match_data.append(match)
            return match_data
        except Exception as e:
            error_msg = ("Failed to retrieve team match data: {}"
                         "".format(str(e)))
            raise TeamDataException(error_msg)

    def _get_projected_data(self, season):
        """
        Returns projected match data related to team
        """
        try:
            match_data = []
            team_id = self.profile_data["id"]
            matches = season.get_season_data()["stats"]["projectedTeamStats"]
            for match in matches:
                if team_id == match[0]:
                    match_data.append(match)
            return match_data
        except Exception as e:
            error_msg = ("Failed to retrieve projected team data: {}"
                         "".format(str(e)))
            raise TeamDataException(error_msg)

    def get_team_id(self):
        """
        Returns the team id
        """
        try:
            return self.profile_data["id"]
        except Exception as e:
            error_msg = ("Failed to retrieve team id: {}"
                         "".format(str(e)))
            raise TeamDataException(error_msg)

    def get_name(self):
        """
        Returns the team name
        """
        try:
            return self.profile_data["name"]
        except Exception as e:
            error_msg = ("Failed to retrieve team name: {}"
                         "".format(str(e)))
            raise TeamDataException(error_msg)

    def get_acronym(self):
        """
        Returns the acronym of the team name
        """
        try:
            return self.profile_data["shortName"]
        except Exception as e:
            error_msg = ("Failed to retrieve team name: {}"
                         "".format(str(e)))
            raise TeamDataException(error_msg)

    def get_region(self):
        """
        Returns the region of the team
        """
        try:
            return self.profile_data["league"]
        except Exception as e:
            error_msg = ("Failed to retrieve region: {}"
                         "".format(str(e)))
            raise TeamDataException(error_msg)

    def get_positions(self):
        """
        Returns a list of all the team's positions
        """
        try:
            return self.profile_data["positions"]
        except Exception as e:
            error_msg = ("Failed to retrieve a list of team positions: {}"
                         "".format(str(e)))
            raise TeamDataException(error_msg)

    def get_riot_id(self):
        """
        Returns the team's riot id
        """
        try:
            return self.profile_data["riotId"]
        except Exception as e:
            error_msg = ("Failed to retrieve the team's riot id: {}"
                         "".format(str(e)))
            raise TeamDataException(error_msg)

    def get_trends_by_week(self):
        """
        Returns a dictionary of all the team's weekly trends
        """
        try:
            return self.profile_data["trendsByWeek"]
        except Exception as e:
            error_msg = ("Failed to retrieve weekly trends: {}"
                         "".format(str(e)))
            raise TeamDataException(error_msg)

    def get_matches_played(self):
        """
        Returns the total matches played
        """
        try:
            return len(self.match_data)
        except Exception as e:
            error_msg = ("Failed to retrieve number of matches played: {}"
                         "".format(str(e)))
            raise TeamDataException(error_msg)

    def get_all_match_stats(self):
        """
        Returns a list of all matches played by the team
        """
        try:
            return self.match_data
        except Exception as e:
            error_msg = ("Failed to retrieve all match stats: {}"
                         "".format(str(e)))
            raise TeamDataException(error_msg)

    def get_match_stats(self, match_number):
        """
        Returns match stats of a team given a number in a range
        from the first match to the most recent match

        @param match_number - # of the match to get
        """
        try:
            match_number = int(match_number)
            if not 0 <= match_number < len(self.match_data):
                raise Exception("Specified number is out of the match range: "
                                "{}".format(match_number))
            match_stats = self.match_data[match_number]
            return match_stats
        except Exception as e:
            error_msg = ("Failed to retrieve match stats: {}"
                         "".format(str(e)))
            raise TeamDataException(error_msg)

    def get_all_projected_stats(self):
        """
        Returns a list of all projected matches to be played by
        the team
        """
        try:
            return self.projected_data
        except Exception as e:
            error_msg = ("Failed to retrieve all projected stats: {}"
                         "".format(str(e)))
            raise TeamDataException(error_msg)

    def get_projected_stats(self, match_number):
        """
        Returns projected stats of a team given a number in a range
        from the first match to the most recent match

        @param match_number - # of the match to get
        """
        try:
            projected_number = int(match_number)
            if not 0 <= projected_number < len(self.projected_data):
                raise Exception("Specified number is out of the match range: "
                                "{}".format(match_number))
            projected_stats = self.projected_data[match_number]
            return projected_stats
        except Exception as e:
            error_msg = ("Failed to retrieve match stats: {}"
                         "".format(str(e)))
            raise TeamDataException(error_msg)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import requests

FANTASY_SEASON_START = 1
FANTASY_SEASON_CURRENT = 16
REGIONS_SUPPORTED = ["na", "lan", "las", "euw", "eune", "oce"]


class SeasonDataException(Exception):
    """Handles SeasonData Exceptions"""


class SeasonData:
    """Handles Season Data requests"""

    def __init__(self, region, season):
        self.season_data = self._fetch_season_data(region, int(season))

    def _fetch_season_data(self, region, season):
        """
        Returns fetched season data

        @param region - region that fantasy season exists in
        @param season - fantasy lcs season number
                        (don't confuse this with the season number of LoL)
        """
        try:
            region = region.lower()
            if region not in REGIONS_SUPPORTED:
                raise Exception("Region not supported: {}"
                                "".format(region))
            if not FANTASY_SEASON_START <= season <= FANTASY_SEASON_CURRENT:
                raise Exception("Season does not exist")
            FANTASY_SEASON_URL = ("https://fantasy.{}.lolesports.com/en-US/api/"
                                  "season/{}".format(region, season))
            data = requests.get(FANTASY_SEASON_URL)
            data.raise_for_status()
            return data.json()
        except Exception as e:
            error_msg = ("Failed to retrieve fantasy season data: {}"
                         "".format(str(e)))
            raise SeasonDataException(error_msg)

    def get_season_data(self):
        """
        Returns season data
        """
        try:
            return self.season_data
        except Exception as e:
            error_msg = ("Failed to retrieve season data: {}"
                         "".format(str(e)))
            raise SeasonDataException(error_msg)

    def get_number_of_weeks(self):
        """
        Returns the number of weeks there are during the fantasy
        season
        """
        try:
            return self.season_data["numberOfWeeks"]
        except Exception as e:
            error_msg = ("Failed to retrieve number of weeks: {}"
                         "".format(str(e)))
            raise SeasonDataException(error_msg)

    def get_all_matches(self):
        """
        Returns a list of all the matches played during the lcs
        """
        try:
            return self.season_data["proMatches"]
        except Exception as e:
            error_msg = ("Failed to retrieve all matches: {}"
                         "".format(str(e)))
            raise SeasonDataException(error_msg)

    def get_all_players(self):
        """
        Returns a list of all the players in lcs
        """
        try:
            return self.season_data["proPlayers"]
        except Exception as e:
            error_msg = ("Failed to retrieve all players: {}"
                         "".format(str(e)))
            raise SeasonDataException(error_msg)

    def get_all_teams(self):
        """
        Returns a list of all the teams in lcs
        """
        try:
            return self.season_data["proTeams"]
        except Exception as e:
            error_msg = ("Failed to retrieve all teams: {}"
                         "".format(str(e)))
            raise SeasonDataException(error_msg)

    def get_all_roster_locks(self):
        """
        Returns a dict of the times when rosters get locked in
        for the week
        """
        try:
            return self.season_data["rosterLocksByWeek"]
        except Exception as e:
            error_msg = ("Failed to retrieve all roster locks: {}"
                         "".format(str(e)))
            raise SeasonDataException(error_msg)

    def get_roster_trends_status(self):
        """
        Returns true if roster trends are disabled
        false if roster trends are enabled
        """
        try:
            return self.season_data["rosterTrendsDisabled"]
        except Exception as e:
            error_msg = ("Failed to retrieve roster trend status: {}"
                         "".format(str(e)))
            raise SeasonDataException(error_msg)

    def get_season_start_time(self):
        """
        Returns the time when the fantasy season begins
        """
        try:
            return self.season_data["seasonBegins"]
        except Exception as e:
            error_msg = ("Failed to retrieve season start time: {}"
                         "".format(str(e)))
            raise SeasonDataException(error_msg)

    def get_season_end_time(self):
        """
        Returns the time when the fantasy season ends
        """
        try:
            return self.season_data["seasonEnds"]
        except Exception as e:
            error_msg = ("Failed to retrieve season end time: {}"
                         "".format(str(e)))
            raise SeasonDataException(error_msg)

    def get_season_name(self):
        """
        Returns the season name
        """
        try:
            return self.season_data["seasonName"]
        except Exception as e:
            error_msg = ("Failed to retrieve season name: {}"
                         "".format(str(e)))
            raise SeasonDataException(error_msg)

    def get_season_split(self):
        """
        Returns the season split
        """
        try:
            return self.season_data["seasonSplit"]
        except Exception as e:
            error_msg = ("Failed to retrieve season split: {}"
                         "".format(str(e)))
            raise SeasonDataException(error_msg)

    def get_season_stats(self):
        """
        Returns a dict of all the stats available
        """
        try:
            return self.season_data["stats"]
        except Exception as e:
            error_msg = ("Failed to retrieve all season stats: {}"
                         "".format(str(e)))
            raise SeasonDataException(error_msg)

    def get_all_actual_player_stats(self):
        """
        Returns a list of all the actual player stats available
        """
        try:
            return self.season_data["stats"]["actualPlayerStats"]
        except Exception as e:
            error_msg = ("Failed to retrieve all of the actual player stats: "
                         "{}".format(str(e)))
            raise SeasonDataException(error_msg)

    def get_all_actual_team_stats(self):
        """
        Returns a list of all the actual team stats available
        """
        try:
            return self.season_data["stats"]["actualTeamStats"]
        except Exception as e:
            error_msg = ("Failed to retrieve all of the actual team stats: "
                         "{}".format(str(e)))
            raise SeasonDataException(error_msg)

    def get_all_projected_player_stats(self):
        """
        Returns a list of all the projected player stats available
        """
        try:
            return self.season_data["stats"]["projectedPlayerStats"]
        except Exception as e:
            error_msg = ("Failed to retrieve all of the projected player "
                         "stats: {}".format(str(e)))
            raise SeasonDataException(error_msg)

    def get_all_projected_team_stats(self):
        """
        Returns a list of all the projected team stats available
        """
        try:
            return self.season_data["stats"]["projectedTeamStats"]
        except Exception as e:
            error_msg = ("Failed to retrieve all of the projected team stats: "
                         "{}".format(str(e)))
            raise SeasonDataException(error_msg)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import requests


REGIONS_SUPPORTED = ["na", "lan", "las", "euw", "eune", "oce"]


class FantasyLeagueException(Exception):
    """Handles FantasyLeague Exceptions"""


class FantasyLeague:
    """Handles fantasy requests"""

    def __init__(self, region, fantasy_league_id):
        self.data = self._get_fantasy_data(region, fantasy_league_id)

    def _get_fantasy_data(self, region, fantasy_league_id):
        """
        Returns data of fantasy league

        @param region - region that fantasy league exists in
        @param fantasy_league_id - id of the fantasy league to search for
        """
        try:
            region = region.lower()
            if region not in REGIONS_SUPPORTED:
                raise Exception("Region not supported: {}"
                                "".format(region))
            FANTASY_URL = ("https://fantasy.{}.lolesports.com/en-US/api/"
                           "league/{}".format(region, fantasy_league_id))
            data = requests.get(FANTASY_URL)
            data.raise_for_status()
            return data.json()
        except Exception as e:
            error_msg = ("Failed to retrieve name of fantasy league: {}"
                         "".format(str(e)))
            raise FantasyLeagueException(error_msg)

    def get_fantasy_id(self):
        """
        Returns the fantasy league id
        """
        try:
            return self.data["id"]
        except Exception as e:
            error_msg = ("Failed to retrieve id of fantasy league: {}"
                         "".format(str(e)))
            raise FantasyLeagueException(error_msg)

    def get_fantasy_name(self):
        """
        Returns the name of the fantasy league
        """
        try:
            return self.data["name"]
        except Exception as e:
            error_msg = ("Failed to retrieve name of fantasy league: {}"
                         "".format(str(e)))
            raise FantasyLeagueException(error_msg)

    def get_fantasy_size(self):
        """
        Returns the number of teams in the fantasy league
        """
        try:
            return self.data["size"]
        except Exception as e:
            error_msg = ("Failed to retrieve the size of the fantasy "
                         "league: {}".format(str(e)))
            raise FantasyLeagueException(error_msg)

    def get_current_week(self):
        """
        Returns the current week number in the fantasy league
        """
        try:
            return self.data["currentWeek"]
        except Exception as e:
            error_msg = ("Failed to retrieve current week of the "
                         "fantasy league: {}".format(str(e)))
            raise FantasyLeagueException(error_msg)

    def get_ignored_weeks(self):
        """
        Returns the total number of weeks ignored in the
        fantasy league
        """
        try:
            return self.data["ignoredWeeks"]
        except Exception as e:
            error_msg = ("Failed to retrieve count of ignored weeks: "
                         "{}".format(str(e)))
            raise FantasyLeagueException(error_msg)

    def get_fantasy_status(self):
        """
        Returns the status of the fantasy league
        """
        try:
            return self.data["status"]
        except Exception as e:
            error_msg = ("Failed to retrieve status of fantasy league: {}"
                         "".format(str(e)))
            raise FantasyLeagueException(error_msg)

    def get_games_counted(self):
        """
        Returns the mode of what games count towards fantasy
        """
        try:
            return self.data["gamesCounted"]
        except Exception as e:
            error_msg = ("Failed to retrieve game mode of fantasy league: {}"
                         "".format(str(e)))
            raise FantasyLeagueException(error_msg)

    def get_points_per_stat(self):
        """
        Returns a dictionary of stats with how many points counted
        per stat
        """
        try:
            return self.data["pointsPerStat"]
        except Exception as e:
            error_msg = ("Failed to retrieve status of fantasy league: {}"
                         "".format(str(e)))
            raise FantasyLeagueException(error_msg)

    def get_fantasy_teams(self):
        """
        Returns a list of fantasy teams
        """
        try:
            return self.data["fantasyTeams"]
        except Exception as e:
            error_msg = ("Failed to retrieve fantasy teams of fantasy league: "
                         "{}".format(str(e)))
            raise FantasyLeagueException(error_msg)

    def get_fantasy_matches(self):
        """
        Returns a list of all the fantasy matches
        """
        try:
            return self.data["fantasyMatches"]
        except Exception as e:
            error_msg = ("Failed to retrieve fantasy matches of fantasy "
                         "league: {}".format(str(e)))
            raise FantasyLeagueException(error_msg)

    def get_fantasy_roster_updates(self):
        """
        Returns a list of all the roster updates
        """
        try:
            return self.data["fantasyRosterUpdates"]
        except Exception as e:
            error_msg = ("Failed to retrieve fantasy roster updates of "
                         "fantasy league: {}".format(str(e)))
            raise FantasyLeagueException(error_msg)

    def get_fantasy_trades(self):
        """
        Returns a list of all the trades made
        """
        try:
            return self.data["trades"]
        except Exception as e:
            error_msg = ("Failed to retrieve trades of fantasy "
                         "league: {}".format(str(e)))
            raise FantasyLeagueException(error_msg)

    def get_fantasy_roster_limits(self):
        """
        Returns the number limit of the roles you're
        allowed to have
        """
        try:
            return self.data["rosterShape"]
        except Exception as e:
            error_msg = ("Failed to retrieve trades of fantasy "
                         "league: {}".format(str(e)))
            raise FantasyLeagueException(error_msg)

    def get_fantasy_role_limit(self):
        """
        Returns the number limit of the same role you're
        allowed to have
        """
        try:
            return self.data["positionCap"]
        except Exception as e:
            error_msg = ("Failed to retrieve position limit of fantasy "
                         "league: {}".format(str(e)))
            raise FantasyLeagueException(error_msg)

    def get_predraft_phase(self):
        """
        Returns predraft phase
        True if league still needs to draft
        False if players already drafted
        """
        try:
            return self.data["predraft"]
        except Exception as e:
            error_msg = ("Failed to retrieve predraft phase: "
                         "{}".format(str(e)))
            raise FantasyLeagueException(error_msg)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

__title__ = 'fantasylcs'
__version__ = '1.1.2'
__author__ = 'Kody Thach'
__repo__ = 'https://github.com/kodycode/League-of-Legends-Fantasy-API-Wrapper'
__license__ = 'MIT License'

from .league import FantasyLeague
from .season import SeasonData
from .player import PlayerData
from .team import TeamData



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup

setup(
    name='fantasylcs',
    version='1.2',
    url='https://github.com/kodycode/Fantasy-LCS-API-Wrapper',
    author='Kody Thach',
    license='MIT License',
    packages=['fantasylcs'],
    description='An unofficial FantasyLCS API Wrapper.',
    long_description=open('README.md', 'r').read(),
    long_description_content_type='text/markdown',
    install_requires=['requests==2.18.4'],
)



class PlayerDataException(Exception):
    """Handles PlayerData Exceptions"""


class PlayerData:
    """Handles Player Data requests"""

    def __init__(self, season, player):
        self.profile_data = self._get_profile(season, player)
        self.match_data = self._get_match_data(season)
        self.projected_data = self._get_projected_data(season)

    def _get_profile(self, season, player):
        """
        Returns profile data of the player

        @param player - id or name of the player to look up
        """
        try:
            try:
                player = int(player)
            except ValueError:
                player = player.lower()
            player_list = season.get_season_data()["proPlayers"]
            for p in player_list:
                if p["id"] == player:
                    return p
                if p["name"].lower() == player:
                    return p
        except Exception as e:
            error_msg = ("Failed to retrieve player profile data: {}"
                         "".format(str(e)))
            raise PlayerDataException(error_msg)

    def _get_match_data(self, season):
        """
        Returns match data related to player
        """
        try:
            match_data = []
            player_id = self.profile_data["id"]
            matches = season.get_season_data()["stats"]["actualPlayerStats"]
            for match in matches:
                if player_id == match[0]:
                    match_data.append(match)
            return match_data
        except Exception as e:
            error_msg = ("Failed to retrieve player match data: {}"
                         "".format(str(e)))
            raise PlayerDataException(error_msg)

    def _get_projected_data(self, season):
        """
        Returns projected match data related to player
        """
        try:
            match_data = []
            player_id = self.profile_data["id"]
            matches = season.get_season_data()["stats"]["projectedPlayerStats"]
            for match in matches:
                if player_id == match[0]:
                    match_data.append(match)
            return match_data
        except Exception as e:
            error_msg = ("Failed to retrieve player match data: {}"
                         "".format(str(e)))
            raise PlayerDataException(error_msg)

    def get_player_id(self):
        """
        Returns the player id
        """
        try:
            return self.profile_data["id"]
        except Exception as e:
            error_msg = ("Failed to retrieve player id: {}"
                         "".format(str(e)))
            raise PlayerDataException(error_msg)

    def get_name(self):
        """
        Returns the player name
        """
        try:
            return self.profile_data["name"]
        except Exception as e:
            error_msg = ("Failed to retrieve player name: {}"
                         "".format(str(e)))
            raise PlayerDataException(error_msg)

    def get_photo_url(self):
        """
        Returns the photo url of the player
        """
        try:
            return self.profile_data["photoUrl"]
        except Exception as e:
            error_msg = ("Failed to retrieve photo url: {}"
                         "".format(str(e)))
            raise PlayerDataException(error_msg)

    def get_positions(self):
        """
        Returns a list of all the player's positions
        """
        try:
            return self.profile_data["positions"]
        except Exception as e:
            error_msg = ("Failed to retrieve a list of player positions: {}"
                         "".format(str(e)))
            raise PlayerDataException(error_msg)

    def get_team_id(self):
        """
        Returns the player's team id
        """
        try:
            return self.profile_data["proTeamId"]
        except Exception as e:
            error_msg = ("Failed to retrieve the player's team id: {}"
                         "".format(str(e)))
            raise PlayerDataException(error_msg)

    def get_riot_id(self):
        """
        Returns the player's riot id
        """
        try:
            return self.profile_data["riotId"]
        except Exception as e:
            error_msg = ("Failed to retrieve the player's riot id: {}"
                         "".format(str(e)))
            raise PlayerDataException(error_msg)

    def get_trends_by_week(self):
        """
        Returns a dictionary of all the player's weekly trends
        """
        try:
            return self.profile_data["trendsByWeek"]
        except Exception as e:
            error_msg = ("Failed to retrieve weekly trends: {}"
                         "".format(str(e)))
            raise PlayerDataException(error_msg)

    def get_matches_played(self):
        """
        Returns the total matches played
        """
        try:
            return len(self.match_data)
        except Exception as e:
            error_msg = ("Failed to retrieve number of matches played: {}"
                         "".format(str(e)))
            raise PlayerDataException(error_msg)

    def get_all_match_stats(self):
        """
        Returns a list of all matches played by the player
        """
        try:
            return self.match_data
        except Exception as e:
            error_msg = ("Failed to retrieve all match stats: {}"
                         "".format(str(e)))
            raise PlayerDataException(error_msg)

    def get_match_stats(self, match_number):
        """
        Returns match stats of a player given a number in a range
        from the first match to the most recent match

        @param match_number - # of the match to get
        """
        try:
            match_number = int(match_number)
            if not 0 <= match_number < len(self.match_data):
                raise Exception("Specified number is out of the match range: "
                                "{}".format(match_number))
            match_stats = self.match_data[match_number]
            return match_stats
        except Exception as e:
            error_msg = ("Failed to retrieve match stats: {}"
                         "".format(str(e)))
            raise PlayerDataException(error_msg)

    def get_all_projected_stats(self):
        """
        Returns a list of all projected matches to be played by
        the player
        """
        try:
            return self.projected_data
        except Exception as e:
            error_msg = ("Failed to retrieve all projected stats: {}"
                         "".format(str(e)))
            raise PlayerDataException(error_msg)

    def get_projected_stats(self, match_number):
        """
        Returns projected stats of a player given a number in a range
        from the first match to the most recent match

        @param match_number - # of the match to get
        """
        try:
            projected_number = int(match_number)
            if not 0 <= projected_number < len(self.projected_data):
                raise Exception("Specified number is out of the match range: "
                                "{}".format(match_number))
            projected_stats = self.projected_data[match_number]
            return projected_stats
        except Exception as e:
            error_msg = ("Failed to retrieve match stats: {}"
                         "".format(str(e)))
            raise PlayerDataException(error_msg)
